``imbalanced_ensemble.sampler``
*********************************

This is the full API documentation of the `imbalanced_ensemble.sampler` module.

.. toctree::
   :maxdepth: 3

   under-samplers
   over-samplers
